@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -57,8 +57,6 @@ class DomainClient(AbstractClient):
     def CheckBatchStatus(self, request):
         """本接口 ( CheckBatchStatus ) 用于查询批量操作日志状态 。
 
-        默认接口请求频率限制：20次/秒。
-
         :param request: Request instance for CheckBatchStatus.
         :type request: :class:`tencentcloud.domain.v20180808.models.CheckBatchStatusRequest`
         :rtype: :class:`tencentcloud.domain.v20180808.models.CheckBatchStatusResponse`
@@ -113,9 +111,7 @@ class DomainClient(AbstractClient):
 
 
     def CreateDomainBatch(self, request):
-        """本接口 ( CreateDomainBatch ) 用于批量注册域名 。
-
-        默认接口请求频率限制：20次/秒。
+        """本接口 ( CreateDomainBatch ) 用于批量域名注册 。
 
         :param request: Request instance for CreateDomainBatch.
         :type request: :class:`tencentcloud.domain.v20180808.models.CreateDomainBatchRequest`
@@ -142,6 +138,34 @@ class DomainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreatePhoneEmail(self, request):
+        """此接口用于创建有效的手机、邮箱
+
+        :param request: Request instance for CreatePhoneEmail.
+        :type request: :class:`tencentcloud.domain.v20180808.models.CreatePhoneEmailRequest`
+        :rtype: :class:`tencentcloud.domain.v20180808.models.CreatePhoneEmailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreatePhoneEmail", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreatePhoneEmailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateTemplate(self, request):
         """本接口 ( CreateTemplate ) 用于添加域名信息模板 。
 
@@ -170,8 +194,36 @@ class DomainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeletePhoneEmail(self, request):
+        """此接口用于删除已验证的手机邮箱
+
+        :param request: Request instance for DeletePhoneEmail.
+        :type request: :class:`tencentcloud.domain.v20180808.models.DeletePhoneEmailRequest`
+        :rtype: :class:`tencentcloud.domain.v20180808.models.DeletePhoneEmailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeletePhoneEmail", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeletePhoneEmailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteTemplate(self, request):
-        """本接口 ( DeleteTemplate ) 用于删除域名信息模板。
+        """本接口 ( DeleteTemplate ) 用于删除信息模板。
 
         :param request: Request instance for DeleteTemplate.
         :type request: :class:`tencentcloud.domain.v20180808.models.DeleteTemplateRequest`
@@ -255,7 +307,7 @@ class DomainClient(AbstractClient):
 
 
     def DescribeDomainBaseInfo(self, request):
-        """本接口 (  DescribeDomainBaseInfo) 获取域名基础信息。
+        """本接口 (  DescribeDomainBaseInfo) 获取域名基本信息。
 
         :param request: Request instance for DescribeDomainBaseInfo.
         :type request: :class:`tencentcloud.domain.v20180808.models.DescribeDomainBaseInfoRequest`
@@ -283,7 +335,7 @@ class DomainClient(AbstractClient):
 
 
     def DescribeDomainNameList(self, request):
-        """本接口 (  DescribeDomainNameList ) 获取域名列表。
+        """本接口 (  DescribeDomainNameList ) 我的域名列表。
 
         :param request: Request instance for DescribeDomainNameList.
         :type request: :class:`tencentcloud.domain.v20180808.models.DescribeDomainNameListRequest`
@@ -338,6 +390,34 @@ class DomainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePhoneEmailList(self, request):
+        """本接口用于获取已验证的手机邮箱列表
+
+        :param request: Request instance for DescribePhoneEmailList.
+        :type request: :class:`tencentcloud.domain.v20180808.models.DescribePhoneEmailListRequest`
+        :rtype: :class:`tencentcloud.domain.v20180808.models.DescribePhoneEmailListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePhoneEmailList", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePhoneEmailListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTemplate(self, request):
         """本接口 (DescribeTemplate) 用于获取模板信息。
 
@@ -367,7 +447,7 @@ class DomainClient(AbstractClient):
 
 
     def DescribeTemplateList(self, request):
-        """本接口 (DescribeTemplateList) 用于获取模板列表。
+        """本接口 (DescribeTemplateList) 用于获取信息模板列表。
 
         :param request: Request instance for DescribeTemplateList.
         :type request: :class:`tencentcloud.domain.v20180808.models.DescribeTemplateListRequest`
@@ -395,9 +475,7 @@ class DomainClient(AbstractClient):
 
 
     def ModifyDomainDNSBatch(self, request):
-        """本接口 ( ModifyDomainDNSBatch) 用于批量修改域名DNS信息 。
-
-        默认接口请求频率限制：20次/秒。
+        """本接口 ( ModifyDomainDNSBatch) 用于批量域名 DNS 修改 。
 
         :param request: Request instance for ModifyDomainDNSBatch.
         :type request: :class:`tencentcloud.domain.v20180808.models.ModifyDomainDNSBatchRequest`
@@ -455,8 +533,6 @@ class DomainClient(AbstractClient):
     def RenewDomainBatch(self, request):
         """本接口 ( RenewDomainBatch ) 用于批量续费域名 。
 
-        默认接口请求频率限制：20次/秒。
-
         :param request: Request instance for RenewDomainBatch.
         :type request: :class:`tencentcloud.domain.v20180808.models.RenewDomainBatchRequest`
         :rtype: :class:`tencentcloud.domain.v20180808.models.RenewDomainBatchResponse`
@@ -482,11 +558,37 @@ class DomainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def SendPhoneEmailCode(self, request):
+        """此接口用于发送手机邮箱验证码。
+
+        :param request: Request instance for SendPhoneEmailCode.
+        :type request: :class:`tencentcloud.domain.v20180808.models.SendPhoneEmailCodeRequest`
+        :rtype: :class:`tencentcloud.domain.v20180808.models.SendPhoneEmailCodeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("SendPhoneEmailCode", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SendPhoneEmailCodeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SetDomainAutoRenew(self, request):
         """本接口 ( SetDomainAutoRenew ) 用于设置域名自动续费。
 
-        默认接口请求频率限制：20次/秒。
-
         :param request: Request instance for SetDomainAutoRenew.
         :type request: :class:`tencentcloud.domain.v20180808.models.SetDomainAutoRenewRequest`
         :rtype: :class:`tencentcloud.domain.v20180808.models.SetDomainAutoRenewResponse`
@@ -515,8 +617,6 @@ class DomainClient(AbstractClient):
     def TransferInDomainBatch(self, request):
         """本接口 ( TransferInDomainBatch ) 用于批量转入域名 。
 
-        默认接口请求频率限制：20次/秒。
-
         :param request: Request instance for TransferInDomainBatch.
         :type request: :class:`tencentcloud.domain.v20180808.models.TransferInDomainBatchRequest`
         :rtype: :class:`tencentcloud.domain.v20180808.models.TransferInDomainBatchResponse`
@@ -543,9 +643,7 @@ class DomainClient(AbstractClient):
 
 
     def TransferProhibitionBatch(self, request):
-        """本接口 ( TransferInDomainBatch ) 用于批量禁止域名转移 。
-
-        默认接口请求频率限制：20次/秒。
+        """本接口 ( TransferProhibitionBatch ) 用于批量禁止域名转移 。
 
         :param request: Request instance for TransferProhibitionBatch.
         :type request: :class:`tencentcloud.domain.v20180808.models.TransferProhibitionBatchRequest`
@@ -573,7 +671,7 @@ class DomainClient(AbstractClient):
 
 
     def UpdateProhibitionBatch(self, request):
-        """本接口 ( UpdateProhibitionBatch ) 用于批量设置禁止域名更新 。
+        """本接口 ( UpdateProhibitionBatch ) 用于批量禁止更新锁。
 
         :param request: Request instance for UpdateProhibitionBatch.
         :type request: :class:`tencentcloud.domain.v20180808.models.UpdateProhibitionBatchRequest`
@@ -601,7 +699,7 @@ class DomainClient(AbstractClient):
 
 
     def UploadImage(self, request):
-        """本接口 ( UploadImage ) 用于上传资质照片 。
+        """本接口 ( UploadImage ) 用于证件图片上传 。
 
         :param request: Request instance for UploadImage.
         :type request: :class:`tencentcloud.domain.v20180808.models.UploadImageRequest`
